ReflectionGeneratorExecutor class

Default executor for the tom_reflection_generator tool (single-command).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(CommandContext context, CliArgs args) Future<ItemResult>
Execute command on a single folder.
executeWithoutTraversal(CliArgs args) Future<ToolResult>
Nested-mode entry point (--nested).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited