createReflectionGeneratorExecutors function
Creates the executor map for the reflection generator tool.
Implementation
Map<String, CommandExecutor> createReflectionGeneratorExecutors() {
return {'default': ReflectionGeneratorExecutor()};
}
Creates the executor map for the reflection generator tool.
Map<String, CommandExecutor> createReflectionGeneratorExecutors() {
return {'default': ReflectionGeneratorExecutor()};
}