SummaryGenerationResult class

Result of generating summaries for a batch of packages.

Constructors

SummaryGenerationResult({required int generated, required int skipped, required int failed, required Map<String, String> errors})
const

Properties

errors Map<String, String>
Error messages for failed packages (keyed by package name).
final
failed int
Number of summaries that failed to generate.
final
generated int
Number of summaries successfully generated.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipped int
Number of summaries that were already cached.
final
total int
Total packages processed.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited