CacheStats class
Statistics about the summary cache.
Constructors
- CacheStats({required int summaryCount, required int totalSizeBytes, required String cacheDirectory})
-
const
Properties
- cacheDirectory → String
-
The cache directory path.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summaryCount → int
-
Number of cached summaries.
final
- totalSizeBytes → int
-
Total size of all cached summaries in bytes.
final
- totalSizeMB → double
-
Total size in megabytes.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited